"use server";

import { SearchParams } from "@/types/searchParams";
import { getServerSession, Session } from "next-auth";
import { nextauthOptions } from "../nextauth-options";
import { requestGetFetch } from "@/utils/fetch";

export async function getAllReports(searchParams?: SearchParams) {
  try {
    const session: Session = await getServerSession(nextauthOptions);
    const token = session?.user?.token;

    const paramsArray = searchParams && Object.entries(searchParams);

    const queryString =
      paramsArray &&
      paramsArray.map(([key, value]) => `${key}=${value}`).join("&");

    const path = "v1/assignments/report" + `?${queryString ? queryString : ""}`;

    const response = await requestGetFetch({
      path,
      options: {
        headers: {
          Authorization: `Bearer ${token}`,
          "Content-Type": "application/json",
          Accept: "application/json",
        },
        cache: "no-store",
      },
    });
    return response;
  } catch (error) {
    throw error;
  }
}
